==> vpython-7.6.4rc6.tar.gz: vpython-7.6.4rc6/CONTRIBUTORS.md <==
# Thank you!

`vpython` development continues thanks to the efforts of the people below.

## Core contributors

+ Bruce Sherwood ([@BruceSherwood](https://github.com/BruceSherwood))
+ Ruth Chabay ([@ruthchabay](https://github.com/ruthchabay))
+ John Coady ([@jcoady](https://github.com/jcoady))
+ Matt Craig ([@mwcraig](https://github.com/mwcraig))
+ Steve Spicklemire ([@sspickle](https://github.com/sspickle))

## Additional contributors

The people below have contributed to the project by identifying and opening
issues, offering improvements to the documentation or contributing code.

We are certain the list is incomplete; please let one of us know by opening an [issue on GitHub](https://github.com/vpython/vpython-jupyter/issues) and we will be happy to add your name!

+ Wayne Decatur ([@fomightez](https://github.com/fomightez))
+ Tomokazu Higuchi ([@higucheese](https://github.com/higucheese))
+ Antti Kaihola ([@akaihola](https://github.com/akaihola))
+ Patrick Melanson ([@pmelanson](https://github.com/pmelanson))
+ Gopal Sharma ([@Hippogriff](https://github.com/Hippogriff))
+ Craig C. Wiegert ([@wigie](https://github.com/wigie))
+ [@jonschull](https://github.com/jonschull)
+ [@KHALAK](https://github.com/KHALAK)
+ [@odidev](https://github.com/odidev)
+ [@qazwsxedcrfvtg14](https://github.com/qazwsxedcrfvtg14)
+ [@russkel](https://github.com/russkel)
+ Kyle Dunn ([@kdunn926](https://github.com/kdunn926))
+ Brian Su ([@brianbbsu](https://github.com/brianbbsu))
+ [@0dminnimda](https://github.com/0dminnimda)
+ Mike Miller ([@Axe319](https://github.com/axe319))

## Full timeline of vpython development

The vpython package grew out of efforts to integrate computing in college physics courses in the 1990s. A full history of [vpython development is here](https://brucesherwood.net/?p=136)

==> vpython-7.6.5b1.tar.gz: vpython-7.6.5b1/CONTRIBUTORS.md <==
# Thank you!

`vpython` development continues thanks to the efforts of the people below.

## Core contributors

+ Bruce Sherwood ([@BruceSherwood](https://github.com/BruceSherwood))
+ Ruth Chabay ([@ruthchabay](https://github.com/ruthchabay))
+ John Coady ([@jcoady](https://github.com/jcoady))
+ Matt Craig ([@mwcraig](https://github.com/mwcraig))
+ Steve Spicklemire ([@sspickle](https://github.com/sspickle))

## Additional contributors

The people below have contributed to the project by identifying and opening
issues, offering improvements to the documentation or contributing code.

We are certain the list is incomplete; please let one of us know by opening an [issue on GitHub](https://github.com/vpython/vpython-jupyter/issues) and we will be happy to add your name!

+ Wayne Decatur ([@fomightez](https://github.com/fomightez))
+ Tomokazu Higuchi ([@higucheese](https://github.com/higucheese))
+ Antti Kaihola ([@akaihola](https://github.com/akaihola))
+ Patrick Melanson ([@pmelanson](https://github.com/pmelanson))
+ Gopal Sharma ([@Hippogriff](https://github.com/Hippogriff))
+ Craig C. Wiegert ([@wigie](https://github.com/wigie))
+ [@jonschull](https://github.com/jonschull)
+ [@KHALAK](https://github.com/KHALAK)
+ [@odidev](https://github.com/odidev)
+ [@qazwsxedcrfvtg14](https://github.com/qazwsxedcrfvtg14)
+ [@russkel](https://github.com/russkel)
+ Kyle Dunn ([@kdunn926](https://github.com/kdunn926))
+ Brian Su ([@brianbbsu](https://github.com/brianbbsu))
+ [@0dminnimda](https://github.com/0dminnimda)
+ Mike Miller ([@Axe319](https://github.com/axe319))
+ Danny Staple ([@dannystaple](https://github.com/dannystaple))
+ Dan Miller ([@danx0r](https://github.com/danx0r))
+ Alex Herrera ([@aherrera1721](https://github.com/aherrera1721))
+ Michał Górny ([@mgorny](https://github.com/mgorny))

## Full timeline of vpython development

The vpython package grew out of efforts to integrate computing in college physics courses in the 1990s. A full history of [vpython development is here](https://brucesherwood.net/?p=136)
